/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"time"

	v1alpha1 "github.com/kubernetes-sigs/kube-batch/pkg/apis/scheduling/v1alpha1"
	scheme "github.com/kubernetes-sigs/kube-batch/pkg/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// QueuesGetter has a method to return a QueueInterface.
// A group's client should implement this interface.
type QueuesGetter interface {
	Queues() QueueInterface
}

// QueueInterface has methods to work with Queue resources.
type QueueInterface interface {
	Create(*v1alpha1.Queue) (*v1alpha1.Queue, error)
	Update(*v1alpha1.Queue) (*v1alpha1.Queue, error)
	UpdateStatus(*v1alpha1.Queue) (*v1alpha1.Queue, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.Queue, error)
	List(opts v1.ListOptions) (*v1alpha1.QueueList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Queue, err error)
	QueueExpansion
}

// queues implements QueueInterface
type queues struct {
	client rest.Interface
}

// newQueues returns a Queues
func newQueues(c *SchedulingV1alpha1Client) *queues {
	return &queues{
		client: c.RESTClient(),
	}
}

// Get takes name of the queue, and returns the corresponding queue object, and an error if there is any.
func (c *queues) Get(name string, options v1.GetOptions) (result *v1alpha1.Queue, err error) {
	result = &v1alpha1.Queue{}
	err = c.client.Get().
		Resource("queues").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of Queues that match those selectors.
func (c *queues) List(opts v1.ListOptions) (result *v1alpha1.QueueList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.QueueList{}
	err = c.client.Get().
		Resource("queues").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested queues.
func (c *queues) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("queues").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a queue and creates it.  Returns the server's representation of the queue, and an error, if there is any.
func (c *queues) Create(queue *v1alpha1.Queue) (result *v1alpha1.Queue, err error) {
	result = &v1alpha1.Queue{}
	err = c.client.Post().
		Resource("queues").
		Body(queue).
		Do().
		Into(result)
	return
}

// Update takes the representation of a queue and updates it. Returns the server's representation of the queue, and an error, if there is any.
func (c *queues) Update(queue *v1alpha1.Queue) (result *v1alpha1.Queue, err error) {
	result = &v1alpha1.Queue{}
	err = c.client.Put().
		Resource("queues").
		Name(queue.Name).
		Body(queue).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *queues) UpdateStatus(queue *v1alpha1.Queue) (result *v1alpha1.Queue, err error) {
	result = &v1alpha1.Queue{}
	err = c.client.Put().
		Resource("queues").
		Name(queue.Name).
		SubResource("status").
		Body(queue).
		Do().
		Into(result)
	return
}

// Delete takes name of the queue and deletes it. Returns an error if one occurs.
func (c *queues) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("queues").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *queues) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("queues").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched queue.
func (c *queues) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Queue, err error) {
	result = &v1alpha1.Queue{}
	err = c.client.Patch(pt).
		Resource("queues").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
